/**
 * Version: 1.3.0
 * Description: jQuery plugin for display of RSS feeds via Google or Yahoo Feed API
 **/
;(function($) {
	'use strict';
	$.fn.oRssFeed = function(options) { //define the defaults for the plugin and how to call it	
		var defaults = { //set default options 
			service: 'google', //google or yahoo 
		    feedUrl: 'http://feeds.reuters.com/reuters/topNews',
			width: '100%',
			limit: 10,
			header: true,
			title: true,
			date: true,
			content: true,
			snippet: true,
			showerror: true,
			errormsg: '',
			characterLimit: 0,
			ssl: true,
			linktarget: '_self',
			scrollItem: true,
			speed: 2000,
			showItems: 3,
			mousePause: true
		};
		var opts = $.extend(defaults, options); //call in the default otions
		return this.each(function() {
			var obj = $(this);
			var html = '';
			obj.width(opts.width);
			if (!obj.hasClass('rssFeed'))
			{
				obj.addClass('rssFeed');
			}
			$.ajax({
				url: (opts.service === "yahoo" ? (opts.ssl ? 'https' : 'http')+"://query.yahooapis.com/v1/public/yql?q=" + encodeURIComponent('SELECT * FROM feednormalizer WHERE output="rss_2.0" AND url ="' + opts.feedUrl + '"') + "&format=json&diagnostics=true" : (opts.ssl ? 'https' : 'http')+"://ajax.googleapis.com/ajax/services/feed/load?v=1.0&q="+ encodeURIComponent(opts.feedUrl)+"&output=json_xml&num=" + opts.limit),
				dataType: "jsonp",
				success: function(data) {
					if (parseInt(data.responseStatus) === 200 || parseInt(data.query.meta.url.status) === 200) {
						var feedData = (opts.service === "yahoo" ? data.query.results.rss.channel.item : data.responseData.feed.entries);
						if (opts.header)
						{
							html +=	'<div class="rssHeader"><a href="'+(opts.service === "yahoo" ? data.query.results.rss.channel.link : data.responseData.feed.link)+'" target="'+opts.linktarget+'" title="'+(opts.service === "yahoo" ? data.query.results.rss.channel.description : data.responseData.feed.description)+'">'+(opts.service === "yahoo" ? data.query.results.rss.channel.title : data.responseData.feed.title)+'</a></div>';
						}
						html += '<div class="rssBody">' +
									'<ul class="rssContainer clearfix">';
											$.each(feedData, function(index, el) {
												if (index < opts.limit)
												{
													var entryDate = new Date((opts.service === "yahoo" ? el.pubDate : el.publishedDate));
													var pubDate = entryDate.toLocaleDateString() + ' ' + entryDate.toLocaleTimeString();
													html += '<li class="rssRow '+((index+1) % 2 === 0 ? 'even' : 'odd')+'" ><div class="vtemrsscontent">';
														if (opts.title)
														{
															html += '<h4 class="itemTitle"><a href="'+el.link+'" target="'+opts.linktarget+'" title="'+el.title+'">'+el.title+'</a></h4>';
														}
														if (opts.date)
														{
															html += '<div class="vtemrssdate">'+ pubDate +'</div>';
														}
														if (opts.content)
														{
															html += '<div class="itemDescription">'+ (opts.service === "yahoo" ? (opts.snippet ? el.description.replace(/(<([^>]+)>)/ig,"") : el.description) : (opts.snippet && el.contentSnippet !== '' ? el.contentSnippet : el.content)).substr(0, (opts.characterLimit > 0 ? opts.characterLimit : 99999))+'</div>';

														}
													html += '</div></li>';
												}
											});
						html +=    '</ul>' +
								'</div>';
						obj.empty().append(html);
						
						// Start scroll feed items
						var maxHeight = 0;
						var itempause = false;	
						var objItems = obj.find('ul.rssContainer');
						var moveUp = function(height, paused)
						{
							if(paused)
							{
								return;
							}
							var	first = objItems.children('li:first').clone();
								objItems.animate({top: '-=' + height + 'px'}, opts.speed, function() {
									objItems.css('top', '0px').children('li:first').remove();
								});
								first.appendTo(objItems);
						};
						if (opts.scrollItem)
						{
							obj.find('.rssBody').css({overflow: 'hidden', position: 'relative'})
								.children().css({position: 'absolute', margin: 0, padding: 0})
								.children().css({margin: 0, padding: 0});
							objItems.children().each(function(){
								if($(this).height() > maxHeight)
								{
									maxHeight = $(this).outerHeight();
								}
							});
							objItems.children().height(maxHeight);
							obj.find('.rssBody').height((maxHeight * opts.showItems) + (parseFloat(objItems.children().css('marginBottom')) * opts.showItems + opts.showItems*2));
							setInterval(function(){ moveUp(maxHeight, itempause); }, opts.speed*1.5);
							if (opts.mousePause){
								obj.hover(function(){itempause = true;},
										  function() {itempause = false;});
							}
						}
						// End scroll feed items
					}
					else
					{
						// Handle error if required
						var msg = '';
						if (opts.showerror)
						{
							if (opts.errormsg !== '') {
								msg += opts.errormsg;
							} else {
								msg += (opts.service === "yahoo" ? 'Error !!!' : data.responseDetails);
							}
							obj.html('<div class="rssError"><p>'+ msg +'</p></div>');
						}
					}
				}
			});
		});//END OF THIS
	};
})(jQuery);